Crate winit_async

Crate winit_async 

winit-async   Action Badge Version Badge License Badge Docs Badge

This crate integrates asynchronous task execution with the winit event loop, allowing !Send futures to be spawned and executed while asynchronously listening for winit events. Timers and I/O are intentionally out of scope for this crate. Use a separate integration for these capabilities. Since this crate is essentially a wrapper around winit, the winit documentation should be consulted for details on window creation, event handling, and platform-specific behavior.

Usage

Examples of how to use the library can be found here.

Contributing

If you find any errors in winit-async or just want to add a new feature feel free to submit a PR.

Re-exports

pub use winit;

Structs

DeviceEventListener
JoinHandle
WindowEventFuture
WindowEvents

Enums

Error

Traits

WindowExtAsync

Functions

available_monitors
create_custom_cursor
create_window
device_events
exit
listen_device_events
owned_display_handle
primary_monitor
resumed
run_app
spawn_local
suspended
system_theme